==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/plugin-mainmenu/mainmenu_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="95"/>
        <source>Search...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="101"/>
        <source>Show/hide main menu</source>
        <translation>Mostra/nascondi menu principale</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Impostazioni del menu principale di LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Testo del pulsante:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Dimensione personalizzata del carattere:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>File del menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>File del menu:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="175"/>
        <source>max. item width:</source>
        <translation>Larghezza massima:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="182"/>
        <source>Show matching entries:</source>
        <translation>Mostra risultati:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="196"/>
        <source>Maximum visible items:</source>
        <translation>Numero massimo:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="203"/>
        <source>Filter menu entries</source>
        <translation>Filtra le categorie</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="223"/>
        <source>Hide menu entries while searching</source>
        <translation>Nascondi menu durante la ricerca</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Scorciatoia da tastiera</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Fai clic sul pulsante per impostare una scorciatoia:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="156"/>
        <source>Choose icon file</source>
        <translation>Seleziona file icona</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="158"/>
        <source>Images (*.svg *.png)</source>
        <translation>File immagini (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="170"/>
        <source>Choose menu file</source>
        <translation>Selezione file del menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="172"/>
        <source>Menu files (*.menu)</source>
        <translation>File di menu (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-mainmenu/mainmenu_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>Mostra/nascondi menu principale</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Impostazioni del menu principale di LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Testo del pulsante:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Dimensione personalizzata del carattere:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>File del menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>File del menu:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation>Larghezza massima:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Mostra risultati:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Numero massimo:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtra le categorie</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Nascondi menu durante la ricerca</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Pulisci campo di ricerca dopo azione</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Scorciatoia da tastiera</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Fai clic sul pulsante per impostare una scorciatoia:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation>Seleziona file icona</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation>File immagini (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>Selezione file del menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>File di menu (*.menu)</translation>
    </message>
</context>
</TS>
